==> qtm-0.5.3.tar.gz: qtm-0.5.3/SysTrayIcon.h <==
/*********************************************************************************

    QTM - Qt-based blog manager
    Copyright (C) 2006 Matthew J Smih

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License (version 2), as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*******************************************************************************/

// SysTrayIcon.h - System tray icon for QTM

#ifndef SYSTRAYICON_H
#define SYSTRAYICON_H

#include <QtGlobal>

#if QT_VERSION >= 0x040200

// #include "useSTI.h"
//#ifdef USE_SYSTRAYICON

#include <QSystemTrayIcon>
#include <QByteArray>
#include <QString>
#include <QClipboard>
#include <QList>
#include <QStringList>
#include <QDomElement>
class QMenu;
class QAction;
class SafeHttp;
class QHttpResponseHeader;
class QuickpostTemplate;

#ifdef Q_WS_MAC
extern void qt_mac_set_dock_menu( QMenu * );
#endif

class SysTrayIcon : public QSystemTrayIcon
{
Q_OBJECT

public:
  SysTrayIcon( QObject *parent = 0 );
  ~SysTrayIcon();
  void setDoubleClickFunction( int );
				    
public slots:
  void configureQuickpostTemplates();

private slots:
  void iconActivated( QSystemTrayIcon::ActivationReason );
  void newDoc();
  void choose();
  void quickpost( QClipboard::Mode mode = QClipboard::Clipboard );
  void quickpostFromTemplate( int, QString );
  void setNewWindowAtStartup( bool );
  void handleResponseHeader( const QHttpResponseHeader & );
  void handleDone( bool );
  void handleHostLookupFailed();
  void doQuit();
  void abortQP();
  
private:
  //enum _cbtextIsURL { No, Yes, Untested };
  //enum _cbtextIsURL cbtextIsURL;
  int activeTemplate;
  QAction *newWindowAtStartup;
  QAction *abortAction;
  QAction *configureTemplates;
#ifndef SUPERMENU
  QAction *quitAction;
#endif
  QList<QuickpostTemplate *> quickpostTemplateActions;
  QMenu *menu;
  QMenu *templateMenu;
  bool _newWindowAtStartup;
  SafeHttp *http;
  QByteArray responseData;
  QString cbtext;
  // bool cbtextIsURL;
  int doubleClickFunction;
  bool httpBusy;
  bool templateQPActive;
  QStringList templateTitleList, templateList;
  QList<int> defaultPublishStatusList;
  void setupQuickpostTemplates();
  void doQP( QString );
  QDomElement templateElement( QDomDocument &, QString, QString, int );
};

#endif
//#endif
#endif

==> qtm-0.5.5.tar.gz: qtm-0.5.5/SysTrayIcon.h <==
/*********************************************************************************

    QTM - Qt-based blog manager
    Copyright (C) 2006 Matthew J Smih

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License (version 2), as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*******************************************************************************/

// SysTrayIcon.h - System tray icon for QTM

#ifndef SYSTRAYICON_H
#define SYSTRAYICON_H

#include <QtGlobal>

#if QT_VERSION >= 0x040200

// #include "useSTI.h"
//#ifdef USE_SYSTRAYICON

#include <QSystemTrayIcon>
#include <QByteArray>
#include <QString>
#include <QClipboard>
#include <QList>
#include <QStringList>
#include <QDomElement>
class QMenu;
class QAction;
class SafeHttp;
class QHttpResponseHeader;
class QuickpostTemplate;

#ifdef Q_WS_MAC
extern void qt_mac_set_dock_menu( QMenu * );
#endif

class SysTrayIcon : public QSystemTrayIcon
{
Q_OBJECT

public:
  SysTrayIcon( QObject *parent = 0 );
  ~SysTrayIcon();
  void setDoubleClickFunction( int );
				    
public slots:
  void configureQuickpostTemplates( QWidget *parent = 0 );

private slots:
  void iconActivated( QSystemTrayIcon::ActivationReason );
  void newDoc();
  void choose();
  void quickpost( QClipboard::Mode mode = QClipboard::Clipboard );
  void quickpostFromTemplate( int, QString );
  void setNewWindowAtStartup( bool );
  void handleResponseHeader( const QHttpResponseHeader & );
  void handleDone( bool );
  void handleHostLookupFailed();
  void doQuit();
  void abortQP();
  
private:
  //enum _cbtextIsURL { No, Yes, Untested };
  //enum _cbtextIsURL cbtextIsURL;
  int activeTemplate;
  QAction *newWindowAtStartup;
  QAction *abortAction;
  QAction *configureTemplates;
#ifndef SUPERMENU
  QAction *quitAction;
#endif
  QList<QuickpostTemplate *> quickpostTemplateActions;
  QMenu *menu;
  QMenu *templateMenu;
  bool _newWindowAtStartup;
  SafeHttp *http;
  QByteArray responseData;
  QString cbtext;
  // bool cbtextIsURL;
  int doubleClickFunction;
  bool httpBusy;
  bool templateQPActive;
  QStringList templateTitleList, templateList;
  QList<int> defaultPublishStatusList;
  void setupQuickpostTemplates();
  void doQP( QString );
  QDomElement templateElement( QDomDocument &, QString, QString, int );
};

#endif
//#endif
#endif
